@@ -95,22 +95,14 @@ void    cleanup_extracted_process(CLEANUP_STATE *state, int type,
 				          const char *buf, int len)
 {
     const char *encoding;
-    int     extra_opts;
+    const char generated_by_cleanup[] = {
+	REC_TYPE_FILT, REC_TYPE_RDR, REC_TYPE_ATTR,
+	REC_TYPE_RRTO, REC_TYPE_ERTO, 0,
+    };
 
     if (msg_verbose)
 	msg_info("extracted envelope %c %.*s", type, len, buf);
 
-    if (type == REC_TYPE_FLGS) {
-	/* Not part of queue file format. */
-	extra_opts = atol(buf);
-	if (extra_opts & ~CLEANUP_FLAG_MASK_EXTRA)
-	    msg_warn("%s: ignoring bad extra flags: 0x%x",
-		     state->queue_id, extra_opts);
-	else
-	    state->flags |= extra_opts;
-	return;
-    }
-
     if (strchr(REC_TYPE_EXTRACT, type) == 0) {
 	msg_warn("%s: message rejected: "
 		 "unexpected record type %d in extracted envelope",
@@ -187,8 +179,14 @@ void    cleanup_extracted_process(CLEANUP_STATE *state, int type,
     if (state->flags & CLEANUP_FLAG_INRCPT)
 	/* Tell qmgr that recipient records are mixed with other information. */
 	state->qmgr_opts |= QMGR_READ_FLAG_MIXED_RCPT_OTHER;
-    cleanup_out(state, type, buf, len);
-    return;
+    if (strchr(generated_by_cleanup, type) != 0) {
+	/* Use our own header/body info instead. */
+	return;
+    } else {
+	/* Pass on other non-recipient record. */
+	cleanup_out(state, type, buf, len);
+	return;
+    }
 }
 
 /* cleanup_extracted_finish - process one extracted envelope record */
