@@ -233,7 +233,7 @@ void    watchdog_pat(void)
 
 #include <vstream.h>
 
-int     main(int unused_argc, char **unused_argv)
+main(int unused_argc, char **unused_argv)
 {
     WATCHDOG *wp;
 
